# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SpringCloudGatewayRouteConfigArgs', 'SpringCloudGatewayRouteConfig']

@pulumi.input_type
class SpringCloudGatewayRouteConfigArgs:
    def __init__(__self__, *,
                 protocol: pulumi.Input[str],
                 spring_cloud_gateway_id: pulumi.Input[str],
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 open_api: Optional[pulumi.Input['SpringCloudGatewayRouteConfigOpenApiArgs']] = None,
                 predicates: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 routes: Optional[pulumi.Input[Sequence[pulumi.Input['SpringCloudGatewayRouteConfigRouteArgs']]]] = None,
                 spring_cloud_app_id: Optional[pulumi.Input[str]] = None,
                 sso_validation_enabled: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a SpringCloudGatewayRouteConfig resource.
        :param pulumi.Input[str] protocol: Specifies the protocol of routed Spring Cloud App. Allowed values are `HTTP` and `HTTPS`.
               
               > **Note:** You likely want to use `HTTPS` in a production environment, since `HTTP` offers no encryption.
        :param pulumi.Input[str] spring_cloud_gateway_id: The ID of the Spring Cloud Gateway. Changing this forces a new Spring Cloud Gateway Route Config to be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] filters: Specifies a list of filters which are used to modify the request before sending it to the target endpoint, or the received response in app level.
        :param pulumi.Input[str] name: The name which should be used for this Spring Cloud Gateway Route Config. Changing this forces a new Spring Cloud Gateway Route Config to be created.
        :param pulumi.Input['SpringCloudGatewayRouteConfigOpenApiArgs'] open_api: One or more `open_api` blocks as defined below.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] predicates: Specifies a list of conditions to evaluate a route for each request in app level. Each predicate may be evaluated against request headers and parameter values. All of the predicates associated with a route must evaluate to true for the route to be matched to the request.
        :param pulumi.Input[Sequence[pulumi.Input['SpringCloudGatewayRouteConfigRouteArgs']]] routes: One or more `route` blocks as defined below.
        :param pulumi.Input[str] spring_cloud_app_id: The ID of the Spring Cloud App.
        :param pulumi.Input[bool] sso_validation_enabled: Should the sso validation be enabled in app level?
        """
        pulumi.set(__self__, "protocol", protocol)
        pulumi.set(__self__, "spring_cloud_gateway_id", spring_cloud_gateway_id)
        if filters is not None:
            pulumi.set(__self__, "filters", filters)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if open_api is not None:
            pulumi.set(__self__, "open_api", open_api)
        if predicates is not None:
            pulumi.set(__self__, "predicates", predicates)
        if routes is not None:
            pulumi.set(__self__, "routes", routes)
        if spring_cloud_app_id is not None:
            pulumi.set(__self__, "spring_cloud_app_id", spring_cloud_app_id)
        if sso_validation_enabled is not None:
            pulumi.set(__self__, "sso_validation_enabled", sso_validation_enabled)

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[str]:
        """
        Specifies the protocol of routed Spring Cloud App. Allowed values are `HTTP` and `HTTPS`.

        > **Note:** You likely want to use `HTTPS` in a production environment, since `HTTP` offers no encryption.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[str]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="springCloudGatewayId")
    def spring_cloud_gateway_id(self) -> pulumi.Input[str]:
        """
        The ID of the Spring Cloud Gateway. Changing this forces a new Spring Cloud Gateway Route Config to be created.
        """
        return pulumi.get(self, "spring_cloud_gateway_id")

    @spring_cloud_gateway_id.setter
    def spring_cloud_gateway_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "spring_cloud_gateway_id", value)

    @property
    @pulumi.getter
    def filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies a list of filters which are used to modify the request before sending it to the target endpoint, or the received response in app level.
        """
        return pulumi.get(self, "filters")

    @filters.setter
    def filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "filters", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this Spring Cloud Gateway Route Config. Changing this forces a new Spring Cloud Gateway Route Config to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="openApi")
    def open_api(self) -> Optional[pulumi.Input['SpringCloudGatewayRouteConfigOpenApiArgs']]:
        """
        One or more `open_api` blocks as defined below.
        """
        return pulumi.get(self, "open_api")

    @open_api.setter
    def open_api(self, value: Optional[pulumi.Input['SpringCloudGatewayRouteConfigOpenApiArgs']]):
        pulumi.set(self, "open_api", value)

    @property
    @pulumi.getter
    def predicates(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies a list of conditions to evaluate a route for each request in app level. Each predicate may be evaluated against request headers and parameter values. All of the predicates associated with a route must evaluate to true for the route to be matched to the request.
        """
        return pulumi.get(self, "predicates")

    @predicates.setter
    def predicates(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "predicates", value)

    @property
    @pulumi.getter
    def routes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SpringCloudGatewayRouteConfigRouteArgs']]]]:
        """
        One or more `route` blocks as defined below.
        """
        return pulumi.get(self, "routes")

    @routes.setter
    def routes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SpringCloudGatewayRouteConfigRouteArgs']]]]):
        pulumi.set(self, "routes", value)

    @property
    @pulumi.getter(name="springCloudAppId")
    def spring_cloud_app_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Spring Cloud App.
        """
        return pulumi.get(self, "spring_cloud_app_id")

    @spring_cloud_app_id.setter
    def spring_cloud_app_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "spring_cloud_app_id", value)

    @property
    @pulumi.getter(name="ssoValidationEnabled")
    def sso_validation_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Should the sso validation be enabled in app level?
        """
        return pulumi.get(self, "sso_validation_enabled")

    @sso_validation_enabled.setter
    def sso_validation_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "sso_validation_enabled", value)


@pulumi.input_type
class _SpringCloudGatewayRouteConfigState:
    def __init__(__self__, *,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 open_api: Optional[pulumi.Input['SpringCloudGatewayRouteConfigOpenApiArgs']] = None,
                 predicates: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 routes: Optional[pulumi.Input[Sequence[pulumi.Input['SpringCloudGatewayRouteConfigRouteArgs']]]] = None,
                 spring_cloud_app_id: Optional[pulumi.Input[str]] = None,
                 spring_cloud_gateway_id: Optional[pulumi.Input[str]] = None,
                 sso_validation_enabled: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering SpringCloudGatewayRouteConfig resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] filters: Specifies a list of filters which are used to modify the request before sending it to the target endpoint, or the received response in app level.
        :param pulumi.Input[str] name: The name which should be used for this Spring Cloud Gateway Route Config. Changing this forces a new Spring Cloud Gateway Route Config to be created.
        :param pulumi.Input['SpringCloudGatewayRouteConfigOpenApiArgs'] open_api: One or more `open_api` blocks as defined below.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] predicates: Specifies a list of conditions to evaluate a route for each request in app level. Each predicate may be evaluated against request headers and parameter values. All of the predicates associated with a route must evaluate to true for the route to be matched to the request.
        :param pulumi.Input[str] protocol: Specifies the protocol of routed Spring Cloud App. Allowed values are `HTTP` and `HTTPS`.
               
               > **Note:** You likely want to use `HTTPS` in a production environment, since `HTTP` offers no encryption.
        :param pulumi.Input[Sequence[pulumi.Input['SpringCloudGatewayRouteConfigRouteArgs']]] routes: One or more `route` blocks as defined below.
        :param pulumi.Input[str] spring_cloud_app_id: The ID of the Spring Cloud App.
        :param pulumi.Input[str] spring_cloud_gateway_id: The ID of the Spring Cloud Gateway. Changing this forces a new Spring Cloud Gateway Route Config to be created.
        :param pulumi.Input[bool] sso_validation_enabled: Should the sso validation be enabled in app level?
        """
        if filters is not None:
            pulumi.set(__self__, "filters", filters)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if open_api is not None:
            pulumi.set(__self__, "open_api", open_api)
        if predicates is not None:
            pulumi.set(__self__, "predicates", predicates)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if routes is not None:
            pulumi.set(__self__, "routes", routes)
        if spring_cloud_app_id is not None:
            pulumi.set(__self__, "spring_cloud_app_id", spring_cloud_app_id)
        if spring_cloud_gateway_id is not None:
            pulumi.set(__self__, "spring_cloud_gateway_id", spring_cloud_gateway_id)
        if sso_validation_enabled is not None:
            pulumi.set(__self__, "sso_validation_enabled", sso_validation_enabled)

    @property
    @pulumi.getter
    def filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies a list of filters which are used to modify the request before sending it to the target endpoint, or the received response in app level.
        """
        return pulumi.get(self, "filters")

    @filters.setter
    def filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "filters", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this Spring Cloud Gateway Route Config. Changing this forces a new Spring Cloud Gateway Route Config to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="openApi")
    def open_api(self) -> Optional[pulumi.Input['SpringCloudGatewayRouteConfigOpenApiArgs']]:
        """
        One or more `open_api` blocks as defined below.
        """
        return pulumi.get(self, "open_api")

    @open_api.setter
    def open_api(self, value: Optional[pulumi.Input['SpringCloudGatewayRouteConfigOpenApiArgs']]):
        pulumi.set(self, "open_api", value)

    @property
    @pulumi.getter
    def predicates(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies a list of conditions to evaluate a route for each request in app level. Each predicate may be evaluated against request headers and parameter values. All of the predicates associated with a route must evaluate to true for the route to be matched to the request.
        """
        return pulumi.get(self, "predicates")

    @predicates.setter
    def predicates(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "predicates", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the protocol of routed Spring Cloud App. Allowed values are `HTTP` and `HTTPS`.

        > **Note:** You likely want to use `HTTPS` in a production environment, since `HTTP` offers no encryption.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter
    def routes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SpringCloudGatewayRouteConfigRouteArgs']]]]:
        """
        One or more `route` blocks as defined below.
        """
        return pulumi.get(self, "routes")

    @routes.setter
    def routes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SpringCloudGatewayRouteConfigRouteArgs']]]]):
        pulumi.set(self, "routes", value)

    @property
    @pulumi.getter(name="springCloudAppId")
    def spring_cloud_app_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Spring Cloud App.
        """
        return pulumi.get(self, "spring_cloud_app_id")

    @spring_cloud_app_id.setter
    def spring_cloud_app_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "spring_cloud_app_id", value)

    @property
    @pulumi.getter(name="springCloudGatewayId")
    def spring_cloud_gateway_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Spring Cloud Gateway. Changing this forces a new Spring Cloud Gateway Route Config to be created.
        """
        return pulumi.get(self, "spring_cloud_gateway_id")

    @spring_cloud_gateway_id.setter
    def spring_cloud_gateway_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "spring_cloud_gateway_id", value)

    @property
    @pulumi.getter(name="ssoValidationEnabled")
    def sso_validation_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Should the sso validation be enabled in app level?
        """
        return pulumi.get(self, "sso_validation_enabled")

    @sso_validation_enabled.setter
    def sso_validation_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "sso_validation_enabled", value)


class SpringCloudGatewayRouteConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 open_api: Optional[pulumi.Input[Union['SpringCloudGatewayRouteConfigOpenApiArgs', 'SpringCloudGatewayRouteConfigOpenApiArgsDict']]] = None,
                 predicates: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 routes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SpringCloudGatewayRouteConfigRouteArgs', 'SpringCloudGatewayRouteConfigRouteArgsDict']]]]] = None,
                 spring_cloud_app_id: Optional[pulumi.Input[str]] = None,
                 spring_cloud_gateway_id: Optional[pulumi.Input[str]] = None,
                 sso_validation_enabled: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        Manages a Spring Cloud Gateway Route Config.

        > **NOTE:** This resource is applicable only for Spring Cloud Service with enterprise tier.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example",
            location="West Europe")
        example_spring_cloud_service = azure.appplatform.SpringCloudService("example",
            name="example",
            location=example.location,
            resource_group_name=example.name,
            sku_name="E0")
        example_spring_cloud_app = azure.appplatform.SpringCloudApp("example",
            name="example",
            resource_group_name=example.name,
            service_name=example_spring_cloud_service.name)
        example_spring_cloud_gateway = azure.appplatform.SpringCloudGateway("example",
            name="default",
            spring_cloud_service_id=example_spring_cloud_service.id)
        example_spring_cloud_gateway_route_config = azure.appplatform.SpringCloudGatewayRouteConfig("example",
            name="example",
            spring_cloud_gateway_id=example_spring_cloud_gateway.id,
            spring_cloud_app_id=example_spring_cloud_app.id,
            protocol="HTTPS",
            routes=[{
                "description": "example description",
                "filters": [
                    "StripPrefix=2",
                    "RateLimit=1,1s",
                ],
                "order": 1,
                "predicates": ["Path=/api5/customer/**"],
                "sso_validation_enabled": True,
                "title": "myApp route config",
                "token_relay": True,
                "uri": "https://www.example.com",
                "classification_tags": [
                    "tag1",
                    "tag2",
                ],
            }])
        ```

        ## Import

        Spring Cloud Gateway Route Configs can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:appplatform/springCloudGatewayRouteConfig:SpringCloudGatewayRouteConfig example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.AppPlatform/spring/service1/gateways/gateway1/routeConfigs/routeConfig1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] filters: Specifies a list of filters which are used to modify the request before sending it to the target endpoint, or the received response in app level.
        :param pulumi.Input[str] name: The name which should be used for this Spring Cloud Gateway Route Config. Changing this forces a new Spring Cloud Gateway Route Config to be created.
        :param pulumi.Input[Union['SpringCloudGatewayRouteConfigOpenApiArgs', 'SpringCloudGatewayRouteConfigOpenApiArgsDict']] open_api: One or more `open_api` blocks as defined below.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] predicates: Specifies a list of conditions to evaluate a route for each request in app level. Each predicate may be evaluated against request headers and parameter values. All of the predicates associated with a route must evaluate to true for the route to be matched to the request.
        :param pulumi.Input[str] protocol: Specifies the protocol of routed Spring Cloud App. Allowed values are `HTTP` and `HTTPS`.
               
               > **Note:** You likely want to use `HTTPS` in a production environment, since `HTTP` offers no encryption.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SpringCloudGatewayRouteConfigRouteArgs', 'SpringCloudGatewayRouteConfigRouteArgsDict']]]] routes: One or more `route` blocks as defined below.
        :param pulumi.Input[str] spring_cloud_app_id: The ID of the Spring Cloud App.
        :param pulumi.Input[str] spring_cloud_gateway_id: The ID of the Spring Cloud Gateway. Changing this forces a new Spring Cloud Gateway Route Config to be created.
        :param pulumi.Input[bool] sso_validation_enabled: Should the sso validation be enabled in app level?
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SpringCloudGatewayRouteConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Spring Cloud Gateway Route Config.

        > **NOTE:** This resource is applicable only for Spring Cloud Service with enterprise tier.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example",
            location="West Europe")
        example_spring_cloud_service = azure.appplatform.SpringCloudService("example",
            name="example",
            location=example.location,
            resource_group_name=example.name,
            sku_name="E0")
        example_spring_cloud_app = azure.appplatform.SpringCloudApp("example",
            name="example",
            resource_group_name=example.name,
            service_name=example_spring_cloud_service.name)
        example_spring_cloud_gateway = azure.appplatform.SpringCloudGateway("example",
            name="default",
            spring_cloud_service_id=example_spring_cloud_service.id)
        example_spring_cloud_gateway_route_config = azure.appplatform.SpringCloudGatewayRouteConfig("example",
            name="example",
            spring_cloud_gateway_id=example_spring_cloud_gateway.id,
            spring_cloud_app_id=example_spring_cloud_app.id,
            protocol="HTTPS",
            routes=[{
                "description": "example description",
                "filters": [
                    "StripPrefix=2",
                    "RateLimit=1,1s",
                ],
                "order": 1,
                "predicates": ["Path=/api5/customer/**"],
                "sso_validation_enabled": True,
                "title": "myApp route config",
                "token_relay": True,
                "uri": "https://www.example.com",
                "classification_tags": [
                    "tag1",
                    "tag2",
                ],
            }])
        ```

        ## Import

        Spring Cloud Gateway Route Configs can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:appplatform/springCloudGatewayRouteConfig:SpringCloudGatewayRouteConfig example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.AppPlatform/spring/service1/gateways/gateway1/routeConfigs/routeConfig1
        ```

        :param str resource_name: The name of the resource.
        :param SpringCloudGatewayRouteConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SpringCloudGatewayRouteConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 open_api: Optional[pulumi.Input[Union['SpringCloudGatewayRouteConfigOpenApiArgs', 'SpringCloudGatewayRouteConfigOpenApiArgsDict']]] = None,
                 predicates: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 routes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SpringCloudGatewayRouteConfigRouteArgs', 'SpringCloudGatewayRouteConfigRouteArgsDict']]]]] = None,
                 spring_cloud_app_id: Optional[pulumi.Input[str]] = None,
                 spring_cloud_gateway_id: Optional[pulumi.Input[str]] = None,
                 sso_validation_enabled: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SpringCloudGatewayRouteConfigArgs.__new__(SpringCloudGatewayRouteConfigArgs)

            __props__.__dict__["filters"] = filters
            __props__.__dict__["name"] = name
            __props__.__dict__["open_api"] = open_api
            __props__.__dict__["predicates"] = predicates
            if protocol is None and not opts.urn:
                raise TypeError("Missing required property 'protocol'")
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["routes"] = routes
            __props__.__dict__["spring_cloud_app_id"] = spring_cloud_app_id
            if spring_cloud_gateway_id is None and not opts.urn:
                raise TypeError("Missing required property 'spring_cloud_gateway_id'")
            __props__.__dict__["spring_cloud_gateway_id"] = spring_cloud_gateway_id
            __props__.__dict__["sso_validation_enabled"] = sso_validation_enabled
        super(SpringCloudGatewayRouteConfig, __self__).__init__(
            'azure:appplatform/springCloudGatewayRouteConfig:SpringCloudGatewayRouteConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            filters: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            open_api: Optional[pulumi.Input[Union['SpringCloudGatewayRouteConfigOpenApiArgs', 'SpringCloudGatewayRouteConfigOpenApiArgsDict']]] = None,
            predicates: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            protocol: Optional[pulumi.Input[str]] = None,
            routes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SpringCloudGatewayRouteConfigRouteArgs', 'SpringCloudGatewayRouteConfigRouteArgsDict']]]]] = None,
            spring_cloud_app_id: Optional[pulumi.Input[str]] = None,
            spring_cloud_gateway_id: Optional[pulumi.Input[str]] = None,
            sso_validation_enabled: Optional[pulumi.Input[bool]] = None) -> 'SpringCloudGatewayRouteConfig':
        """
        Get an existing SpringCloudGatewayRouteConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] filters: Specifies a list of filters which are used to modify the request before sending it to the target endpoint, or the received response in app level.
        :param pulumi.Input[str] name: The name which should be used for this Spring Cloud Gateway Route Config. Changing this forces a new Spring Cloud Gateway Route Config to be created.
        :param pulumi.Input[Union['SpringCloudGatewayRouteConfigOpenApiArgs', 'SpringCloudGatewayRouteConfigOpenApiArgsDict']] open_api: One or more `open_api` blocks as defined below.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] predicates: Specifies a list of conditions to evaluate a route for each request in app level. Each predicate may be evaluated against request headers and parameter values. All of the predicates associated with a route must evaluate to true for the route to be matched to the request.
        :param pulumi.Input[str] protocol: Specifies the protocol of routed Spring Cloud App. Allowed values are `HTTP` and `HTTPS`.
               
               > **Note:** You likely want to use `HTTPS` in a production environment, since `HTTP` offers no encryption.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SpringCloudGatewayRouteConfigRouteArgs', 'SpringCloudGatewayRouteConfigRouteArgsDict']]]] routes: One or more `route` blocks as defined below.
        :param pulumi.Input[str] spring_cloud_app_id: The ID of the Spring Cloud App.
        :param pulumi.Input[str] spring_cloud_gateway_id: The ID of the Spring Cloud Gateway. Changing this forces a new Spring Cloud Gateway Route Config to be created.
        :param pulumi.Input[bool] sso_validation_enabled: Should the sso validation be enabled in app level?
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SpringCloudGatewayRouteConfigState.__new__(_SpringCloudGatewayRouteConfigState)

        __props__.__dict__["filters"] = filters
        __props__.__dict__["name"] = name
        __props__.__dict__["open_api"] = open_api
        __props__.__dict__["predicates"] = predicates
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["routes"] = routes
        __props__.__dict__["spring_cloud_app_id"] = spring_cloud_app_id
        __props__.__dict__["spring_cloud_gateway_id"] = spring_cloud_gateway_id
        __props__.__dict__["sso_validation_enabled"] = sso_validation_enabled
        return SpringCloudGatewayRouteConfig(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def filters(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Specifies a list of filters which are used to modify the request before sending it to the target endpoint, or the received response in app level.
        """
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name which should be used for this Spring Cloud Gateway Route Config. Changing this forces a new Spring Cloud Gateway Route Config to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="openApi")
    def open_api(self) -> pulumi.Output[Optional['outputs.SpringCloudGatewayRouteConfigOpenApi']]:
        """
        One or more `open_api` blocks as defined below.
        """
        return pulumi.get(self, "open_api")

    @property
    @pulumi.getter
    def predicates(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Specifies a list of conditions to evaluate a route for each request in app level. Each predicate may be evaluated against request headers and parameter values. All of the predicates associated with a route must evaluate to true for the route to be matched to the request.
        """
        return pulumi.get(self, "predicates")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[str]:
        """
        Specifies the protocol of routed Spring Cloud App. Allowed values are `HTTP` and `HTTPS`.

        > **Note:** You likely want to use `HTTPS` in a production environment, since `HTTP` offers no encryption.
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter
    def routes(self) -> pulumi.Output[Optional[Sequence['outputs.SpringCloudGatewayRouteConfigRoute']]]:
        """
        One or more `route` blocks as defined below.
        """
        return pulumi.get(self, "routes")

    @property
    @pulumi.getter(name="springCloudAppId")
    def spring_cloud_app_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the Spring Cloud App.
        """
        return pulumi.get(self, "spring_cloud_app_id")

    @property
    @pulumi.getter(name="springCloudGatewayId")
    def spring_cloud_gateway_id(self) -> pulumi.Output[str]:
        """
        The ID of the Spring Cloud Gateway. Changing this forces a new Spring Cloud Gateway Route Config to be created.
        """
        return pulumi.get(self, "spring_cloud_gateway_id")

    @property
    @pulumi.getter(name="ssoValidationEnabled")
    def sso_validation_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Should the sso validation be enabled in app level?
        """
        return pulumi.get(self, "sso_validation_enabled")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetSharedImageGalleryResult',
    'AwaitableGetSharedImageGalleryResult',
    'get_shared_image_gallery',
    'get_shared_image_gallery_output',
]

@pulumi.output_type
class GetSharedImageGalleryResult:
    """
    A collection of values returned by getSharedImageGallery.
    """
    def __init__(__self__, description=None, id=None, image_names=None, location=None, name=None, resource_group_name=None, tags=None, unique_name=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image_names and not isinstance(image_names, list):
            raise TypeError("Expected argument 'image_names' to be a list")
        pulumi.set(__self__, "image_names", image_names)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if unique_name and not isinstance(unique_name, str):
            raise TypeError("Expected argument 'unique_name' to be a str")
        pulumi.set(__self__, "unique_name", unique_name)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A description for the Shared Image Gallery.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageNames")
    def image_names(self) -> Sequence[str]:
        """
        A list of Shared Image names within this Shared Image Gallery.
        """
        return pulumi.get(self, "image_names")

    @property
    @pulumi.getter
    def location(self) -> str:
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> str:
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, str]:
        """
        A mapping of tags which are assigned to the Shared Image Gallery.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="uniqueName")
    def unique_name(self) -> str:
        """
        The unique name assigned to the Shared Image Gallery.
        """
        return pulumi.get(self, "unique_name")


class AwaitableGetSharedImageGalleryResult(GetSharedImageGalleryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSharedImageGalleryResult(
            description=self.description,
            id=self.id,
            image_names=self.image_names,
            location=self.location,
            name=self.name,
            resource_group_name=self.resource_group_name,
            tags=self.tags,
            unique_name=self.unique_name)


def get_shared_image_gallery(name: Optional[str] = None,
                             resource_group_name: Optional[str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSharedImageGalleryResult:
    """
    Use this data source to access information about an existing Shared Image Gallery.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.compute.get_shared_image_gallery(name="my-image-gallery",
        resource_group_name="example-resources")
    ```


    :param str name: The name of the Shared Image Gallery.
    :param str resource_group_name: The name of the Resource Group in which the Shared Image Gallery exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:compute/getSharedImageGallery:getSharedImageGallery', __args__, opts=opts, typ=GetSharedImageGalleryResult).value

    return AwaitableGetSharedImageGalleryResult(
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        image_names=pulumi.get(__ret__, 'image_names'),
        location=pulumi.get(__ret__, 'location'),
        name=pulumi.get(__ret__, 'name'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'),
        tags=pulumi.get(__ret__, 'tags'),
        unique_name=pulumi.get(__ret__, 'unique_name'))
def get_shared_image_gallery_output(name: Optional[pulumi.Input[str]] = None,
                                    resource_group_name: Optional[pulumi.Input[str]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSharedImageGalleryResult]:
    """
    Use this data source to access information about an existing Shared Image Gallery.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.compute.get_shared_image_gallery(name="my-image-gallery",
        resource_group_name="example-resources")
    ```


    :param str name: The name of the Shared Image Gallery.
    :param str resource_group_name: The name of the Resource Group in which the Shared Image Gallery exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:compute/getSharedImageGallery:getSharedImageGallery', __args__, opts=opts, typ=GetSharedImageGalleryResult)
    return __ret__.apply(lambda __response__: GetSharedImageGalleryResult(
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        image_names=pulumi.get(__response__, 'image_names'),
        location=pulumi.get(__response__, 'location'),
        name=pulumi.get(__response__, 'name'),
        resource_group_name=pulumi.get(__response__, 'resource_group_name'),
        tags=pulumi.get(__response__, 'tags'),
        unique_name=pulumi.get(__response__, 'unique_name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .account import *
from .cassandra_cluster import *
from .cassandra_datacenter import *
from .cassandra_keyspace import *
from .cassandra_table import *
from .get_account import *
from .get_mongo_database import *
from .get_restorable_database_accounts import *
from .get_sql_database import *
from .get_sql_role_definition import *
from .gremlin_database import *
from .gremlin_graph import *
from .mongo_cluster import *
from .mongo_collection import *
from .mongo_database import *
from .mongo_role_definition import *
from .mongo_user_definition import *
from .postgresql_cluster import *
from .postgresql_coordinator_configuration import *
from .postgresql_firewall_rule import *
from .postgresql_node_configuration import *
from .postgresql_role import *
from .sql_container import *
from .sql_database import *
from .sql_dedicated_gateway import *
from .sql_function import *
from .sql_role_assignment import *
from .sql_role_definition import *
from .sql_stored_procedure import *
from .sql_trigger import *
from .table import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetExtendedLocationsResult',
    'AwaitableGetExtendedLocationsResult',
    'get_extended_locations',
    'get_extended_locations_output',
]

@pulumi.output_type
class GetExtendedLocationsResult:
    """
    A collection of values returned by getExtendedLocations.
    """
    def __init__(__self__, extended_locations=None, id=None, location=None):
        if extended_locations and not isinstance(extended_locations, list):
            raise TypeError("Expected argument 'extended_locations' to be a list")
        pulumi.set(__self__, "extended_locations", extended_locations)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)

    @property
    @pulumi.getter(name="extendedLocations")
    def extended_locations(self) -> Sequence[str]:
        """
        The available extended locations for the Azure Location.
        """
        return pulumi.get(self, "extended_locations")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def location(self) -> str:
        return pulumi.get(self, "location")


class AwaitableGetExtendedLocationsResult(GetExtendedLocationsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetExtendedLocationsResult(
            extended_locations=self.extended_locations,
            id=self.id,
            location=self.location)


def get_extended_locations(location: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetExtendedLocationsResult:
    """
    This data source return the available Extended Locations for a specific Azure Region.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.core.get_extended_locations(location="West Europe")
    ```


    :param str location: The Azure location to retrieve the Extended Locations for.
    """
    __args__ = dict()
    __args__['location'] = location
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:core/getExtendedLocations:getExtendedLocations', __args__, opts=opts, typ=GetExtendedLocationsResult).value

    return AwaitableGetExtendedLocationsResult(
        extended_locations=pulumi.get(__ret__, 'extended_locations'),
        id=pulumi.get(__ret__, 'id'),
        location=pulumi.get(__ret__, 'location'))
def get_extended_locations_output(location: Optional[pulumi.Input[str]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetExtendedLocationsResult]:
    """
    This data source return the available Extended Locations for a specific Azure Region.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.core.get_extended_locations(location="West Europe")
    ```


    :param str location: The Azure location to retrieve the Extended Locations for.
    """
    __args__ = dict()
    __args__['location'] = location
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:core/getExtendedLocations:getExtendedLocations', __args__, opts=opts, typ=GetExtendedLocationsResult)
    return __ret__.apply(lambda __response__: GetExtendedLocationsResult(
        extended_locations=pulumi.get(__response__, 'extended_locations'),
        id=pulumi.get(__response__, 'id'),
        location=pulumi.get(__response__, 'location')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VirtualMachineArgs', 'VirtualMachine']

@pulumi.input_type
class VirtualMachineArgs:
    def __init__(__self__, *,
                 virtual_machine_id: pulumi.Input[str],
                 assessment: Optional[pulumi.Input['VirtualMachineAssessmentArgs']] = None,
                 auto_backup: Optional[pulumi.Input['VirtualMachineAutoBackupArgs']] = None,
                 auto_patching: Optional[pulumi.Input['VirtualMachineAutoPatchingArgs']] = None,
                 key_vault_credential: Optional[pulumi.Input['VirtualMachineKeyVaultCredentialArgs']] = None,
                 r_services_enabled: Optional[pulumi.Input[bool]] = None,
                 sql_connectivity_port: Optional[pulumi.Input[int]] = None,
                 sql_connectivity_type: Optional[pulumi.Input[str]] = None,
                 sql_connectivity_update_password: Optional[pulumi.Input[str]] = None,
                 sql_connectivity_update_username: Optional[pulumi.Input[str]] = None,
                 sql_instance: Optional[pulumi.Input['VirtualMachineSqlInstanceArgs']] = None,
                 sql_license_type: Optional[pulumi.Input[str]] = None,
                 sql_virtual_machine_group_id: Optional[pulumi.Input[str]] = None,
                 storage_configuration: Optional[pulumi.Input['VirtualMachineStorageConfigurationArgs']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 wsfc_domain_credential: Optional[pulumi.Input['VirtualMachineWsfcDomainCredentialArgs']] = None):
        """
        The set of arguments for constructing a VirtualMachine resource.
        :param pulumi.Input[str] virtual_machine_id: The ID of the Virtual Machine. Changing this forces a new resource to be created.
        :param pulumi.Input['VirtualMachineAssessmentArgs'] assessment: An `assessment` block as defined below.
        :param pulumi.Input['VirtualMachineAutoBackupArgs'] auto_backup: An `auto_backup` block as defined below. This block can be added to an existing resource, but removing this block forces a new resource to be created.
        :param pulumi.Input['VirtualMachineAutoPatchingArgs'] auto_patching: An `auto_patching` block as defined below.
        :param pulumi.Input['VirtualMachineKeyVaultCredentialArgs'] key_vault_credential: An `key_vault_credential` block as defined below.
        :param pulumi.Input[bool] r_services_enabled: Should R Services be enabled?
        :param pulumi.Input[int] sql_connectivity_port: The SQL Server port. Defaults to `1433`.
        :param pulumi.Input[str] sql_connectivity_type: The connectivity type used for this SQL Server. Possible values are `LOCAL`, `PRIVATE` and `PUBLIC`. Defaults to `PRIVATE`.
        :param pulumi.Input[str] sql_connectivity_update_password: The SQL Server sysadmin login password.
        :param pulumi.Input[str] sql_connectivity_update_username: The SQL Server sysadmin login to create.
        :param pulumi.Input['VirtualMachineSqlInstanceArgs'] sql_instance: A `sql_instance` block as defined below.
        :param pulumi.Input[str] sql_license_type: The SQL Server license type. Possible values are `AHUB` (Azure Hybrid Benefit), `DR` (Disaster Recovery), and `PAYG` (Pay-As-You-Go). Changing this forces a new resource to be created.
        :param pulumi.Input[str] sql_virtual_machine_group_id: The ID of the SQL Virtual Machine Group that the SQL Virtual Machine belongs to.
        :param pulumi.Input['VirtualMachineStorageConfigurationArgs'] storage_configuration: An `storage_configuration` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input['VirtualMachineWsfcDomainCredentialArgs'] wsfc_domain_credential: A `wsfc_domain_credential` block as defined below
        """
        pulumi.set(__self__, "virtual_machine_id", virtual_machine_id)
        if assessment is not None:
            pulumi.set(__self__, "assessment", assessment)
        if auto_backup is not None:
            pulumi.set(__self__, "auto_backup", auto_backup)
        if auto_patching is not None:
            pulumi.set(__self__, "auto_patching", auto_patching)
        if key_vault_credential is not None:
            pulumi.set(__self__, "key_vault_credential", key_vault_credential)
        if r_services_enabled is not None:
            pulumi.set(__self__, "r_services_enabled", r_services_enabled)
        if sql_connectivity_port is not None:
            pulumi.set(__self__, "sql_connectivity_port", sql_connectivity_port)
        if sql_connectivity_type is not None:
            pulumi.set(__self__, "sql_connectivity_type", sql_connectivity_type)
        if sql_connectivity_update_password is not None:
            pulumi.set(__self__, "sql_connectivity_update_password", sql_connectivity_update_password)
        if sql_connectivity_update_username is not None:
            pulumi.set(__self__, "sql_connectivity_update_username", sql_connectivity_update_username)
        if sql_instance is not None:
            pulumi.set(__self__, "sql_instance", sql_instance)
        if sql_license_type is not None:
            pulumi.set(__self__, "sql_license_type", sql_license_type)
        if sql_virtual_machine_group_id is not None:
            pulumi.set(__self__, "sql_virtual_machine_group_id", sql_virtual_machine_group_id)
        if storage_configuration is not None:
            pulumi.set(__self__, "storage_configuration", storage_configuration)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if wsfc_domain_credential is not None:
            pulumi.set(__self__, "wsfc_domain_credential", wsfc_domain_credential)

    @property
    @pulumi.getter(name="virtualMachineId")
    def virtual_machine_id(self) -> pulumi.Input[str]:
        """
        The ID of the Virtual Machine. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "virtual_machine_id")

    @virtual_machine_id.setter
    def virtual_machine_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "virtual_machine_id", value)

    @property
    @pulumi.getter
    def assessment(self) -> Optional[pulumi.Input['VirtualMachineAssessmentArgs']]:
        """
        An `assessment` block as defined below.
        """
        return pulumi.get(self, "assessment")

    @assessment.setter
    def assessment(self, value: Optional[pulumi.Input['VirtualMachineAssessmentArgs']]):
        pulumi.set(self, "assessment", value)

    @property
    @pulumi.getter(name="autoBackup")
    def auto_backup(self) -> Optional[pulumi.Input['VirtualMachineAutoBackupArgs']]:
        """
        An `auto_backup` block as defined below. This block can be added to an existing resource, but removing this block forces a new resource to be created.
        """
        return pulumi.get(self, "auto_backup")

    @auto_backup.setter
    def auto_backup(self, value: Optional[pulumi.Input['VirtualMachineAutoBackupArgs']]):
        pulumi.set(self, "auto_backup", value)

    @property
    @pulumi.getter(name="autoPatching")
    def auto_patching(self) -> Optional[pulumi.Input['VirtualMachineAutoPatchingArgs']]:
        """
        An `auto_patching` block as defined below.
        """
        return pulumi.get(self, "auto_patching")

    @auto_patching.setter
    def auto_patching(self, value: Optional[pulumi.Input['VirtualMachineAutoPatchingArgs']]):
        pulumi.set(self, "auto_patching", value)

    @property
    @pulumi.getter(name="keyVaultCredential")
    def key_vault_credential(self) -> Optional[pulumi.Input['VirtualMachineKeyVaultCredentialArgs']]:
        """
        An `key_vault_credential` block as defined below.
        """
        return pulumi.get(self, "key_vault_credential")

    @key_vault_credential.setter
    def key_vault_credential(self, value: Optional[pulumi.Input['VirtualMachineKeyVaultCredentialArgs']]):
        pulumi.set(self, "key_vault_credential", value)

    @property
    @pulumi.getter(name="rServicesEnabled")
    def r_services_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Should R Services be enabled?
        """
        return pulumi.get(self, "r_services_enabled")

    @r_services_enabled.setter
    def r_services_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "r_services_enabled", value)

    @property
    @pulumi.getter(name="sqlConnectivityPort")
    def sql_connectivity_port(self) -> Optional[pulumi.Input[int]]:
        """
        The SQL Server port. Defaults to `1433`.
        """
        return pulumi.get(self, "sql_connectivity_port")

    @sql_connectivity_port.setter
    def sql_connectivity_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "sql_connectivity_port", value)

    @property
    @pulumi.getter(name="sqlConnectivityType")
    def sql_connectivity_type(self) -> Optional[pulumi.Input[str]]:
        """
        The connectivity type used for this SQL Server. Possible values are `LOCAL`, `PRIVATE` and `PUBLIC`. Defaults to `PRIVATE`.
        """
        return pulumi.get(self, "sql_connectivity_type")

    @sql_connectivity_type.setter
    def sql_connectivity_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sql_connectivity_type", value)

    @property
    @pulumi.getter(name="sqlConnectivityUpdatePassword")
    def sql_connectivity_update_password(self) -> Optional[pulumi.Input[str]]:
        """
        The SQL Server sysadmin login password.
        """
        return pulumi.get(self, "sql_connectivity_update_password")

    @sql_connectivity_update_password.setter
    def sql_connectivity_update_password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sql_connectivity_update_password", value)

    @property
    @pulumi.getter(name="sqlConnectivityUpdateUsername")
    def sql_connectivity_update_username(self) -> Optional[pulumi.Input[str]]:
        """
        The SQL Server sysadmin login to create.
        """
        return pulumi.get(self, "sql_connectivity_update_username")

    @sql_connectivity_update_username.setter
    def sql_connectivity_update_username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sql_connectivity_update_username", value)

    @property
    @pulumi.getter(name="sqlInstance")
    def sql_instance(self) -> Optional[pulumi.Input['VirtualMachineSqlInstanceArgs']]:
        """
        A `sql_instance` block as defined below.
        """
        return pulumi.get(self, "sql_instance")

    @sql_instance.setter
    def sql_instance(self, value: Optional[pulumi.Input['VirtualMachineSqlInstanceArgs']]):
        pulumi.set(self, "sql_instance", value)

    @property
    @pulumi.getter(name="sqlLicenseType")
    def sql_license_type(self) -> Optional[pulumi.Input[str]]:
        """
        The SQL Server license type. Possible values are `AHUB` (Azure Hybrid Benefit), `DR` (Disaster Recovery), and `PAYG` (Pay-As-You-Go). Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "sql_license_type")

    @sql_license_type.setter
    def sql_license_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sql_license_type", value)

    @property
    @pulumi.getter(name="sqlVirtualMachineGroupId")
    def sql_virtual_machine_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the SQL Virtual Machine Group that the SQL Virtual Machine belongs to.
        """
        return pulumi.get(self, "sql_virtual_machine_group_id")

    @sql_virtual_machine_group_id.setter
    def sql_virtual_machine_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sql_virtual_machine_group_id", value)

    @property
    @pulumi.getter(name="storageConfiguration")
    def storage_configuration(self) -> Optional[pulumi.Input['VirtualMachineStorageConfigurationArgs']]:
        """
        An `storage_configuration` block as defined below.
        """
        return pulumi.get(self, "storage_configuration")

    @storage_configuration.setter
    def storage_configuration(self, value: Optional[pulumi.Input['VirtualMachineStorageConfigurationArgs']]):
        pulumi.set(self, "storage_configuration", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="wsfcDomainCredential")
    def wsfc_domain_credential(self) -> Optional[pulumi.Input['VirtualMachineWsfcDomainCredentialArgs']]:
        """
        A `wsfc_domain_credential` block as defined below
        """
        return pulumi.get(self, "wsfc_domain_credential")

    @wsfc_domain_credential.setter
    def wsfc_domain_credential(self, value: Optional[pulumi.Input['VirtualMachineWsfcDomainCredentialArgs']]):
        pulumi.set(self, "wsfc_domain_credential", value)


@pulumi.input_type
class _VirtualMachineState:
    def __init__(__self__, *,
                 assessment: Optional[pulumi.Input['VirtualMachineAssessmentArgs']] = None,
                 auto_backup: Optional[pulumi.Input['VirtualMachineAutoBackupArgs']] = None,
                 auto_patching: Optional[pulumi.Input['VirtualMachineAutoPatchingArgs']] = None,
                 key_vault_credential: Optional[pulumi.Input['VirtualMachineKeyVaultCredentialArgs']] = None,
                 r_services_enabled: Optional[pulumi.Input[bool]] = None,
                 sql_connectivity_port: Optional[pulumi.Input[int]] = None,
                 sql_connectivity_type: Optional[pulumi.Input[str]] = None,
                 sql_connectivity_update_password: Optional[pulumi.Input[str]] = None,
                 sql_connectivity_update_username: Optional[pulumi.Input[str]] = None,
                 sql_instance: Optional[pulumi.Input['VirtualMachineSqlInstanceArgs']] = None,
                 sql_license_type: Optional[pulumi.Input[str]] = None,
                 sql_virtual_machine_group_id: Optional[pulumi.Input[str]] = None,
                 storage_configuration: Optional[pulumi.Input['VirtualMachineStorageConfigurationArgs']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 virtual_machine_id: Optional[pulumi.Input[str]] = None,
                 wsfc_domain_credential: Optional[pulumi.Input['VirtualMachineWsfcDomainCredentialArgs']] = None):
        """
        Input properties used for looking up and filtering VirtualMachine resources.
        :param pulumi.Input['VirtualMachineAssessmentArgs'] assessment: An `assessment` block as defined below.
        :param pulumi.Input['VirtualMachineAutoBackupArgs'] auto_backup: An `auto_backup` block as defined below. This block can be added to an existing resource, but removing this block forces a new resource to be created.
        :param pulumi.Input['VirtualMachineAutoPatchingArgs'] auto_patching: An `auto_patching` block as defined below.
        :param pulumi.Input['VirtualMachineKeyVaultCredentialArgs'] key_vault_credential: An `key_vault_credential` block as defined below.
        :param pulumi.Input[bool] r_services_enabled: Should R Services be enabled?
        :param pulumi.Input[int] sql_connectivity_port: The SQL Server port. Defaults to `1433`.
        :param pulumi.Input[str] sql_connectivity_type: The connectivity type used for this SQL Server. Possible values are `LOCAL`, `PRIVATE` and `PUBLIC`. Defaults to `PRIVATE`.
        :param pulumi.Input[str] sql_connectivity_update_password: The SQL Server sysadmin login password.
        :param pulumi.Input[str] sql_connectivity_update_username: The SQL Server sysadmin login to create.
        :param pulumi.Input['VirtualMachineSqlInstanceArgs'] sql_instance: A `sql_instance` block as defined below.
        :param pulumi.Input[str] sql_license_type: The SQL Server license type. Possible values are `AHUB` (Azure Hybrid Benefit), `DR` (Disaster Recovery), and `PAYG` (Pay-As-You-Go). Changing this forces a new resource to be created.
        :param pulumi.Input[str] sql_virtual_machine_group_id: The ID of the SQL Virtual Machine Group that the SQL Virtual Machine belongs to.
        :param pulumi.Input['VirtualMachineStorageConfigurationArgs'] storage_configuration: An `storage_configuration` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] virtual_machine_id: The ID of the Virtual Machine. Changing this forces a new resource to be created.
        :param pulumi.Input['VirtualMachineWsfcDomainCredentialArgs'] wsfc_domain_credential: A `wsfc_domain_credential` block as defined below
        """
        if assessment is not None:
            pulumi.set(__self__, "assessment", assessment)
        if auto_backup is not None:
            pulumi.set(__self__, "auto_backup", auto_backup)
        if auto_patching is not None:
            pulumi.set(__self__, "auto_patching", auto_patching)
        if key_vault_credential is not None:
            pulumi.set(__self__, "key_vault_credential", key_vault_credential)
        if r_services_enabled is not None:
            pulumi.set(__self__, "r_services_enabled", r_services_enabled)
        if sql_connectivity_port is not None:
            pulumi.set(__self__, "sql_connectivity_port", sql_connectivity_port)
        if sql_connectivity_type is not None:
            pulumi.set(__self__, "sql_connectivity_type", sql_connectivity_type)
        if sql_connectivity_update_password is not None:
            pulumi.set(__self__, "sql_connectivity_update_password", sql_connectivity_update_password)
        if sql_connectivity_update_username is not None:
            pulumi.set(__self__, "sql_connectivity_update_username", sql_connectivity_update_username)
        if sql_instance is not None:
            pulumi.set(__self__, "sql_instance", sql_instance)
        if sql_license_type is not None:
            pulumi.set(__self__, "sql_license_type", sql_license_type)
        if sql_virtual_machine_group_id is not None:
            pulumi.set(__self__, "sql_virtual_machine_group_id", sql_virtual_machine_group_id)
        if storage_configuration is not None:
            pulumi.set(__self__, "storage_configuration", storage_configuration)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if virtual_machine_id is not None:
            pulumi.set(__self__, "virtual_machine_id", virtual_machine_id)
        if wsfc_domain_credential is not None:
            pulumi.set(__self__, "wsfc_domain_credential", wsfc_domain_credential)

    @property
    @pulumi.getter
    def assessment(self) -> Optional[pulumi.Input['VirtualMachineAssessmentArgs']]:
        """
        An `assessment` block as defined below.
        """
        return pulumi.get(self, "assessment")

    @assessment.setter
    def assessment(self, value: Optional[pulumi.Input['VirtualMachineAssessmentArgs']]):
        pulumi.set(self, "assessment", value)

    @property
    @pulumi.getter(name="autoBackup")
    def auto_backup(self) -> Optional[pulumi.Input['VirtualMachineAutoBackupArgs']]:
        """
        An `auto_backup` block as defined below. This block can be added to an existing resource, but removing this block forces a new resource to be created.
        """
        return pulumi.get(self, "auto_backup")

    @auto_backup.setter
    def auto_backup(self, value: Optional[pulumi.Input['VirtualMachineAutoBackupArgs']]):
        pulumi.set(self, "auto_backup", value)

    @property
    @pulumi.getter(name="autoPatching")
    def auto_patching(self) -> Optional[pulumi.Input['VirtualMachineAutoPatchingArgs']]:
        """
        An `auto_patching` block as defined below.
        """
        return pulumi.get(self, "auto_patching")

    @auto_patching.setter
    def auto_patching(self, value: Optional[pulumi.Input['VirtualMachineAutoPatchingArgs']]):
        pulumi.set(self, "auto_patching", value)

    @property
    @pulumi.getter(name="keyVaultCredential")
    def key_vault_credential(self) -> Optional[pulumi.Input['VirtualMachineKeyVaultCredentialArgs']]:
        """
        An `key_vault_credential` block as defined below.
        """
        return pulumi.get(self, "key_vault_credential")

    @key_vault_credential.setter
    def key_vault_credential(self, value: Optional[pulumi.Input['VirtualMachineKeyVaultCredentialArgs']]):
        pulumi.set(self, "key_vault_credential", value)

    @property
    @pulumi.getter(name="rServicesEnabled")
    def r_services_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Should R Services be enabled?
        """
        return pulumi.get(self, "r_services_enabled")

    @r_services_enabled.setter
    def r_services_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "r_services_enabled", value)

    @property
    @pulumi.getter(name="sqlConnectivityPort")
    def sql_connectivity_port(self) -> Optional[pulumi.Input[int]]:
        """
        The SQL Server port. Defaults to `1433`.
        """
        return pulumi.get(self, "sql_connectivity_port")

    @sql_connectivity_port.setter
    def sql_connectivity_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "sql_connectivity_port", value)

    @property
    @pulumi.getter(name="sqlConnectivityType")
    def sql_connectivity_type(self) -> Optional[pulumi.Input[str]]:
        """
        The connectivity type used for this SQL Server. Possible values are `LOCAL`, `PRIVATE` and `PUBLIC`. Defaults to `PRIVATE`.
        """
        return pulumi.get(self, "sql_connectivity_type")

    @sql_connectivity_type.setter
    def sql_connectivity_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sql_connectivity_type", value)

    @property
    @pulumi.getter(name="sqlConnectivityUpdatePassword")
    def sql_connectivity_update_password(self) -> Optional[pulumi.Input[str]]:
        """
        The SQL Server sysadmin login password.
        """
        return pulumi.get(self, "sql_connectivity_update_password")

    @sql_connectivity_update_password.setter
    def sql_connectivity_update_password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sql_connectivity_update_password", value)

    @property
    @pulumi.getter(name="sqlConnectivityUpdateUsername")
    def sql_connectivity_update_username(self) -> Optional[pulumi.Input[str]]:
        """
        The SQL Server sysadmin login to create.
        """
        return pulumi.get(self, "sql_connectivity_update_username")

    @sql_connectivity_update_username.setter
    def sql_connectivity_update_username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sql_connectivity_update_username", value)

    @property
    @pulumi.getter(name="sqlInstance")
    def sql_instance(self) -> Optional[pulumi.Input['VirtualMachineSqlInstanceArgs']]:
        """
        A `sql_instance` block as defined below.
        """
        return pulumi.get(self, "sql_instance")

    @sql_instance.setter
    def sql_instance(self, value: Optional[pulumi.Input['VirtualMachineSqlInstanceArgs']]):
        pulumi.set(self, "sql_instance", value)

    @property
    @pulumi.getter(name="sqlLicenseType")
    def sql_license_type(self) -> Optional[pulumi.Input[str]]:
        """
        The SQL Server license type. Possible values are `AHUB` (Azure Hybrid Benefit), `DR` (Disaster Recovery), and `PAYG` (Pay-As-You-Go). Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "sql_license_type")

    @sql_license_type.setter
    def sql_license_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sql_license_type", value)

    @property
    @pulumi.getter(name="sqlVirtualMachineGroupId")
    def sql_virtual_machine_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the SQL Virtual Machine Group that the SQL Virtual Machine belongs to.
        """
        return pulumi.get(self, "sql_virtual_machine_group_id")

    @sql_virtual_machine_group_id.setter
    def sql_virtual_machine_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sql_virtual_machine_group_id", value)

    @property
    @pulumi.getter(name="storageConfiguration")
    def storage_configuration(self) -> Optional[pulumi.Input['VirtualMachineStorageConfigurationArgs']]:
        """
        An `storage_configuration` block as defined below.
        """
        return pulumi.get(self, "storage_configuration")

    @storage_configuration.setter
    def storage_configuration(self, value: Optional[pulumi.Input['VirtualMachineStorageConfigurationArgs']]):
        pulumi.set(self, "storage_configuration", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="virtualMachineId")
    def virtual_machine_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Virtual Machine. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "virtual_machine_id")

    @virtual_machine_id.setter
    def virtual_machine_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "virtual_machine_id", value)

    @property
    @pulumi.getter(name="wsfcDomainCredential")
    def wsfc_domain_credential(self) -> Optional[pulumi.Input['VirtualMachineWsfcDomainCredentialArgs']]:
        """
        A `wsfc_domain_credential` block as defined below
        """
        return pulumi.get(self, "wsfc_domain_credential")

    @wsfc_domain_credential.setter
    def wsfc_domain_credential(self, value: Optional[pulumi.Input['VirtualMachineWsfcDomainCredentialArgs']]):
        pulumi.set(self, "wsfc_domain_credential", value)


class VirtualMachine(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 assessment: Optional[pulumi.Input[Union['VirtualMachineAssessmentArgs', 'VirtualMachineAssessmentArgsDict']]] = None,
                 auto_backup: Optional[pulumi.Input[Union['VirtualMachineAutoBackupArgs', 'VirtualMachineAutoBackupArgsDict']]] = None,
                 auto_patching: Optional[pulumi.Input[Union['VirtualMachineAutoPatchingArgs', 'VirtualMachineAutoPatchingArgsDict']]] = None,
                 key_vault_credential: Optional[pulumi.Input[Union['VirtualMachineKeyVaultCredentialArgs', 'VirtualMachineKeyVaultCredentialArgsDict']]] = None,
                 r_services_enabled: Optional[pulumi.Input[bool]] = None,
                 sql_connectivity_port: Optional[pulumi.Input[int]] = None,
                 sql_connectivity_type: Optional[pulumi.Input[str]] = None,
                 sql_connectivity_update_password: Optional[pulumi.Input[str]] = None,
                 sql_connectivity_update_username: Optional[pulumi.Input[str]] = None,
                 sql_instance: Optional[pulumi.Input[Union['VirtualMachineSqlInstanceArgs', 'VirtualMachineSqlInstanceArgsDict']]] = None,
                 sql_license_type: Optional[pulumi.Input[str]] = None,
                 sql_virtual_machine_group_id: Optional[pulumi.Input[str]] = None,
                 storage_configuration: Optional[pulumi.Input[Union['VirtualMachineStorageConfigurationArgs', 'VirtualMachineStorageConfigurationArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 virtual_machine_id: Optional[pulumi.Input[str]] = None,
                 wsfc_domain_credential: Optional[pulumi.Input[Union['VirtualMachineWsfcDomainCredentialArgs', 'VirtualMachineWsfcDomainCredentialArgsDict']]] = None,
                 __props__=None):
        """
        Manages a Microsoft SQL Virtual Machine

        ## Example Usage

        This example provisions a brief Managed Microsoft SQL Virtual Machine.

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.compute.get_virtual_machine(name="example-vm",
            resource_group_name="example-resources")
        example_virtual_machine = azure.mssql.VirtualMachine("example",
            virtual_machine_id=example.id,
            sql_license_type="PAYG",
            r_services_enabled=True,
            sql_connectivity_port=1433,
            sql_connectivity_type="PRIVATE",
            sql_connectivity_update_password="Password1234!",
            sql_connectivity_update_username="sqllogin",
            auto_patching={
                "day_of_week": "Sunday",
                "maintenance_window_duration_in_minutes": 60,
                "maintenance_window_starting_hour": 2,
            })
        ```

        ## Import

        Microsoft SQL Virtual Machines can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:mssql/virtualMachine:VirtualMachine example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.SqlVirtualMachine/sqlVirtualMachines/example1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['VirtualMachineAssessmentArgs', 'VirtualMachineAssessmentArgsDict']] assessment: An `assessment` block as defined below.
        :param pulumi.Input[Union['VirtualMachineAutoBackupArgs', 'VirtualMachineAutoBackupArgsDict']] auto_backup: An `auto_backup` block as defined below. This block can be added to an existing resource, but removing this block forces a new resource to be created.
        :param pulumi.Input[Union['VirtualMachineAutoPatchingArgs', 'VirtualMachineAutoPatchingArgsDict']] auto_patching: An `auto_patching` block as defined below.
        :param pulumi.Input[Union['VirtualMachineKeyVaultCredentialArgs', 'VirtualMachineKeyVaultCredentialArgsDict']] key_vault_credential: An `key_vault_credential` block as defined below.
        :param pulumi.Input[bool] r_services_enabled: Should R Services be enabled?
        :param pulumi.Input[int] sql_connectivity_port: The SQL Server port. Defaults to `1433`.
        :param pulumi.Input[str] sql_connectivity_type: The connectivity type used for this SQL Server. Possible values are `LOCAL`, `PRIVATE` and `PUBLIC`. Defaults to `PRIVATE`.
        :param pulumi.Input[str] sql_connectivity_update_password: The SQL Server sysadmin login password.
        :param pulumi.Input[str] sql_connectivity_update_username: The SQL Server sysadmin login to create.
        :param pulumi.Input[Union['VirtualMachineSqlInstanceArgs', 'VirtualMachineSqlInstanceArgsDict']] sql_instance: A `sql_instance` block as defined below.
        :param pulumi.Input[str] sql_license_type: The SQL Server license type. Possible values are `AHUB` (Azure Hybrid Benefit), `DR` (Disaster Recovery), and `PAYG` (Pay-As-You-Go). Changing this forces a new resource to be created.
        :param pulumi.Input[str] sql_virtual_machine_group_id: The ID of the SQL Virtual Machine Group that the SQL Virtual Machine belongs to.
        :param pulumi.Input[Union['VirtualMachineStorageConfigurationArgs', 'VirtualMachineStorageConfigurationArgsDict']] storage_configuration: An `storage_configuration` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] virtual_machine_id: The ID of the Virtual Machine. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['VirtualMachineWsfcDomainCredentialArgs', 'VirtualMachineWsfcDomainCredentialArgsDict']] wsfc_domain_credential: A `wsfc_domain_credential` block as defined below
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VirtualMachineArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Microsoft SQL Virtual Machine

        ## Example Usage

        This example provisions a brief Managed Microsoft SQL Virtual Machine.

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.compute.get_virtual_machine(name="example-vm",
            resource_group_name="example-resources")
        example_virtual_machine = azure.mssql.VirtualMachine("example",
            virtual_machine_id=example.id,
            sql_license_type="PAYG",
            r_services_enabled=True,
            sql_connectivity_port=1433,
            sql_connectivity_type="PRIVATE",
            sql_connectivity_update_password="Password1234!",
            sql_connectivity_update_username="sqllogin",
            auto_patching={
                "day_of_week": "Sunday",
                "maintenance_window_duration_in_minutes": 60,
                "maintenance_window_starting_hour": 2,
            })
        ```

        ## Import

        Microsoft SQL Virtual Machines can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:mssql/virtualMachine:VirtualMachine example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.SqlVirtualMachine/sqlVirtualMachines/example1
        ```

        :param str resource_name: The name of the resource.
        :param VirtualMachineArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VirtualMachineArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 assessment: Optional[pulumi.Input[Union['VirtualMachineAssessmentArgs', 'VirtualMachineAssessmentArgsDict']]] = None,
                 auto_backup: Optional[pulumi.Input[Union['VirtualMachineAutoBackupArgs', 'VirtualMachineAutoBackupArgsDict']]] = None,
                 auto_patching: Optional[pulumi.Input[Union['VirtualMachineAutoPatchingArgs', 'VirtualMachineAutoPatchingArgsDict']]] = None,
                 key_vault_credential: Optional[pulumi.Input[Union['VirtualMachineKeyVaultCredentialArgs', 'VirtualMachineKeyVaultCredentialArgsDict']]] = None,
                 r_services_enabled: Optional[pulumi.Input[bool]] = None,
                 sql_connectivity_port: Optional[pulumi.Input[int]] = None,
                 sql_connectivity_type: Optional[pulumi.Input[str]] = None,
                 sql_connectivity_update_password: Optional[pulumi.Input[str]] = None,
                 sql_connectivity_update_username: Optional[pulumi.Input[str]] = None,
                 sql_instance: Optional[pulumi.Input[Union['VirtualMachineSqlInstanceArgs', 'VirtualMachineSqlInstanceArgsDict']]] = None,
                 sql_license_type: Optional[pulumi.Input[str]] = None,
                 sql_virtual_machine_group_id: Optional[pulumi.Input[str]] = None,
                 storage_configuration: Optional[pulumi.Input[Union['VirtualMachineStorageConfigurationArgs', 'VirtualMachineStorageConfigurationArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 virtual_machine_id: Optional[pulumi.Input[str]] = None,
                 wsfc_domain_credential: Optional[pulumi.Input[Union['VirtualMachineWsfcDomainCredentialArgs', 'VirtualMachineWsfcDomainCredentialArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VirtualMachineArgs.__new__(VirtualMachineArgs)

            __props__.__dict__["assessment"] = assessment
            __props__.__dict__["auto_backup"] = auto_backup
            __props__.__dict__["auto_patching"] = auto_patching
            __props__.__dict__["key_vault_credential"] = key_vault_credential
            __props__.__dict__["r_services_enabled"] = r_services_enabled
            __props__.__dict__["sql_connectivity_port"] = sql_connectivity_port
            __props__.__dict__["sql_connectivity_type"] = sql_connectivity_type
            __props__.__dict__["sql_connectivity_update_password"] = None if sql_connectivity_update_password is None else pulumi.Output.secret(sql_connectivity_update_password)
            __props__.__dict__["sql_connectivity_update_username"] = None if sql_connectivity_update_username is None else pulumi.Output.secret(sql_connectivity_update_username)
            __props__.__dict__["sql_instance"] = sql_instance
            __props__.__dict__["sql_license_type"] = sql_license_type
            __props__.__dict__["sql_virtual_machine_group_id"] = sql_virtual_machine_group_id
            __props__.__dict__["storage_configuration"] = storage_configuration
            __props__.__dict__["tags"] = tags
            if virtual_machine_id is None and not opts.urn:
                raise TypeError("Missing required property 'virtual_machine_id'")
            __props__.__dict__["virtual_machine_id"] = virtual_machine_id
            __props__.__dict__["wsfc_domain_credential"] = wsfc_domain_credential
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["sqlConnectivityUpdatePassword", "sqlConnectivityUpdateUsername"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(VirtualMachine, __self__).__init__(
            'azure:mssql/virtualMachine:VirtualMachine',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            assessment: Optional[pulumi.Input[Union['VirtualMachineAssessmentArgs', 'VirtualMachineAssessmentArgsDict']]] = None,
            auto_backup: Optional[pulumi.Input[Union['VirtualMachineAutoBackupArgs', 'VirtualMachineAutoBackupArgsDict']]] = None,
            auto_patching: Optional[pulumi.Input[Union['VirtualMachineAutoPatchingArgs', 'VirtualMachineAutoPatchingArgsDict']]] = None,
            key_vault_credential: Optional[pulumi.Input[Union['VirtualMachineKeyVaultCredentialArgs', 'VirtualMachineKeyVaultCredentialArgsDict']]] = None,
            r_services_enabled: Optional[pulumi.Input[bool]] = None,
            sql_connectivity_port: Optional[pulumi.Input[int]] = None,
            sql_connectivity_type: Optional[pulumi.Input[str]] = None,
            sql_connectivity_update_password: Optional[pulumi.Input[str]] = None,
            sql_connectivity_update_username: Optional[pulumi.Input[str]] = None,
            sql_instance: Optional[pulumi.Input[Union['VirtualMachineSqlInstanceArgs', 'VirtualMachineSqlInstanceArgsDict']]] = None,
            sql_license_type: Optional[pulumi.Input[str]] = None,
            sql_virtual_machine_group_id: Optional[pulumi.Input[str]] = None,
            storage_configuration: Optional[pulumi.Input[Union['VirtualMachineStorageConfigurationArgs', 'VirtualMachineStorageConfigurationArgsDict']]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            virtual_machine_id: Optional[pulumi.Input[str]] = None,
            wsfc_domain_credential: Optional[pulumi.Input[Union['VirtualMachineWsfcDomainCredentialArgs', 'VirtualMachineWsfcDomainCredentialArgsDict']]] = None) -> 'VirtualMachine':
        """
        Get an existing VirtualMachine resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['VirtualMachineAssessmentArgs', 'VirtualMachineAssessmentArgsDict']] assessment: An `assessment` block as defined below.
        :param pulumi.Input[Union['VirtualMachineAutoBackupArgs', 'VirtualMachineAutoBackupArgsDict']] auto_backup: An `auto_backup` block as defined below. This block can be added to an existing resource, but removing this block forces a new resource to be created.
        :param pulumi.Input[Union['VirtualMachineAutoPatchingArgs', 'VirtualMachineAutoPatchingArgsDict']] auto_patching: An `auto_patching` block as defined below.
        :param pulumi.Input[Union['VirtualMachineKeyVaultCredentialArgs', 'VirtualMachineKeyVaultCredentialArgsDict']] key_vault_credential: An `key_vault_credential` block as defined below.
        :param pulumi.Input[bool] r_services_enabled: Should R Services be enabled?
        :param pulumi.Input[int] sql_connectivity_port: The SQL Server port. Defaults to `1433`.
        :param pulumi.Input[str] sql_connectivity_type: The connectivity type used for this SQL Server. Possible values are `LOCAL`, `PRIVATE` and `PUBLIC`. Defaults to `PRIVATE`.
        :param pulumi.Input[str] sql_connectivity_update_password: The SQL Server sysadmin login password.
        :param pulumi.Input[str] sql_connectivity_update_username: The SQL Server sysadmin login to create.
        :param pulumi.Input[Union['VirtualMachineSqlInstanceArgs', 'VirtualMachineSqlInstanceArgsDict']] sql_instance: A `sql_instance` block as defined below.
        :param pulumi.Input[str] sql_license_type: The SQL Server license type. Possible values are `AHUB` (Azure Hybrid Benefit), `DR` (Disaster Recovery), and `PAYG` (Pay-As-You-Go). Changing this forces a new resource to be created.
        :param pulumi.Input[str] sql_virtual_machine_group_id: The ID of the SQL Virtual Machine Group that the SQL Virtual Machine belongs to.
        :param pulumi.Input[Union['VirtualMachineStorageConfigurationArgs', 'VirtualMachineStorageConfigurationArgsDict']] storage_configuration: An `storage_configuration` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] virtual_machine_id: The ID of the Virtual Machine. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['VirtualMachineWsfcDomainCredentialArgs', 'VirtualMachineWsfcDomainCredentialArgsDict']] wsfc_domain_credential: A `wsfc_domain_credential` block as defined below
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VirtualMachineState.__new__(_VirtualMachineState)

        __props__.__dict__["assessment"] = assessment
        __props__.__dict__["auto_backup"] = auto_backup
        __props__.__dict__["auto_patching"] = auto_patching
        __props__.__dict__["key_vault_credential"] = key_vault_credential
        __props__.__dict__["r_services_enabled"] = r_services_enabled
        __props__.__dict__["sql_connectivity_port"] = sql_connectivity_port
        __props__.__dict__["sql_connectivity_type"] = sql_connectivity_type
        __props__.__dict__["sql_connectivity_update_password"] = sql_connectivity_update_password
        __props__.__dict__["sql_connectivity_update_username"] = sql_connectivity_update_username
        __props__.__dict__["sql_instance"] = sql_instance
        __props__.__dict__["sql_license_type"] = sql_license_type
        __props__.__dict__["sql_virtual_machine_group_id"] = sql_virtual_machine_group_id
        __props__.__dict__["storage_configuration"] = storage_configuration
        __props__.__dict__["tags"] = tags
        __props__.__dict__["virtual_machine_id"] = virtual_machine_id
        __props__.__dict__["wsfc_domain_credential"] = wsfc_domain_credential
        return VirtualMachine(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def assessment(self) -> pulumi.Output[Optional['outputs.VirtualMachineAssessment']]:
        """
        An `assessment` block as defined below.
        """
        return pulumi.get(self, "assessment")

    @property
    @pulumi.getter(name="autoBackup")
    def auto_backup(self) -> pulumi.Output[Optional['outputs.VirtualMachineAutoBackup']]:
        """
        An `auto_backup` block as defined below. This block can be added to an existing resource, but removing this block forces a new resource to be created.
        """
        return pulumi.get(self, "auto_backup")

    @property
    @pulumi.getter(name="autoPatching")
    def auto_patching(self) -> pulumi.Output[Optional['outputs.VirtualMachineAutoPatching']]:
        """
        An `auto_patching` block as defined below.
        """
        return pulumi.get(self, "auto_patching")

    @property
    @pulumi.getter(name="keyVaultCredential")
    def key_vault_credential(self) -> pulumi.Output[Optional['outputs.VirtualMachineKeyVaultCredential']]:
        """
        An `key_vault_credential` block as defined below.
        """
        return pulumi.get(self, "key_vault_credential")

    @property
    @pulumi.getter(name="rServicesEnabled")
    def r_services_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Should R Services be enabled?
        """
        return pulumi.get(self, "r_services_enabled")

    @property
    @pulumi.getter(name="sqlConnectivityPort")
    def sql_connectivity_port(self) -> pulumi.Output[Optional[int]]:
        """
        The SQL Server port. Defaults to `1433`.
        """
        return pulumi.get(self, "sql_connectivity_port")

    @property
    @pulumi.getter(name="sqlConnectivityType")
    def sql_connectivity_type(self) -> pulumi.Output[Optional[str]]:
        """
        The connectivity type used for this SQL Server. Possible values are `LOCAL`, `PRIVATE` and `PUBLIC`. Defaults to `PRIVATE`.
        """
        return pulumi.get(self, "sql_connectivity_type")

    @property
    @pulumi.getter(name="sqlConnectivityUpdatePassword")
    def sql_connectivity_update_password(self) -> pulumi.Output[Optional[str]]:
        """
        The SQL Server sysadmin login password.
        """
        return pulumi.get(self, "sql_connectivity_update_password")

    @property
    @pulumi.getter(name="sqlConnectivityUpdateUsername")
    def sql_connectivity_update_username(self) -> pulumi.Output[Optional[str]]:
        """
        The SQL Server sysadmin login to create.
        """
        return pulumi.get(self, "sql_connectivity_update_username")

    @property
    @pulumi.getter(name="sqlInstance")
    def sql_instance(self) -> pulumi.Output[Optional['outputs.VirtualMachineSqlInstance']]:
        """
        A `sql_instance` block as defined below.
        """
        return pulumi.get(self, "sql_instance")

    @property
    @pulumi.getter(name="sqlLicenseType")
    def sql_license_type(self) -> pulumi.Output[Optional[str]]:
        """
        The SQL Server license type. Possible values are `AHUB` (Azure Hybrid Benefit), `DR` (Disaster Recovery), and `PAYG` (Pay-As-You-Go). Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "sql_license_type")

    @property
    @pulumi.getter(name="sqlVirtualMachineGroupId")
    def sql_virtual_machine_group_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the SQL Virtual Machine Group that the SQL Virtual Machine belongs to.
        """
        return pulumi.get(self, "sql_virtual_machine_group_id")

    @property
    @pulumi.getter(name="storageConfiguration")
    def storage_configuration(self) -> pulumi.Output[Optional['outputs.VirtualMachineStorageConfiguration']]:
        """
        An `storage_configuration` block as defined below.
        """
        return pulumi.get(self, "storage_configuration")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="virtualMachineId")
    def virtual_machine_id(self) -> pulumi.Output[str]:
        """
        The ID of the Virtual Machine. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "virtual_machine_id")

    @property
    @pulumi.getter(name="wsfcDomainCredential")
    def wsfc_domain_credential(self) -> pulumi.Output[Optional['outputs.VirtualMachineWsfcDomainCredential']]:
        """
        A `wsfc_domain_credential` block as defined below
        """
        return pulumi.get(self, "wsfc_domain_credential")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ComputeClusterIdentity',
    'ComputeClusterScaleSettings',
    'ComputeClusterSsh',
    'ComputeInstanceAssignToUser',
    'ComputeInstanceIdentity',
    'ComputeInstanceSsh',
    'InferenceClusterIdentity',
    'InferenceClusterSsl',
    'SynapseSparkIdentity',
    'WorkspaceEncryption',
    'WorkspaceFeatureStore',
    'WorkspaceIdentity',
    'WorkspaceManagedNetwork',
    'WorkspaceServerlessCompute',
    'GetWorkspaceIdentityResult',
]

@pulumi.output_type
class ComputeClusterIdentity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "identityIds":
            suggest = "identity_ids"
        elif key == "principalId":
            suggest = "principal_id"
        elif key == "tenantId":
            suggest = "tenant_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ComputeClusterIdentity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ComputeClusterIdentity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ComputeClusterIdentity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 identity_ids: Optional[Sequence[str]] = None,
                 principal_id: Optional[str] = None,
                 tenant_id: Optional[str] = None):
        """
        :param str type: Specifies the type of Managed Service Identity that should be configured on this Machine Learning Compute Cluster. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both). Changing this forces a new resource to be created.
        :param Sequence[str] identity_ids: Specifies a list of User Assigned Managed Identity IDs to be assigned to this Machine Learning Compute Cluster. Changing this forces a new resource to be created.
               
               > **NOTE:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        :param str principal_id: The Principal ID for the Service Principal associated with the Managed Service Identity of this Machine Learning Compute Cluster.
        :param str tenant_id: The Tenant ID for the Service Principal associated with the Managed Service Identity of this Machine Learning Compute Cluster.
        """
        pulumi.set(__self__, "type", type)
        if identity_ids is not None:
            pulumi.set(__self__, "identity_ids", identity_ids)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Specifies the type of Managed Service Identity that should be configured on this Machine Learning Compute Cluster. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both). Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[Sequence[str]]:
        """
        Specifies a list of User Assigned Managed Identity IDs to be assigned to this Machine Learning Compute Cluster. Changing this forces a new resource to be created.

        > **NOTE:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        return pulumi.get(self, "identity_ids")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[str]:
        """
        The Principal ID for the Service Principal associated with the Managed Service Identity of this Machine Learning Compute Cluster.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[str]:
        """
        The Tenant ID for the Service Principal associated with the Managed Service Identity of this Machine Learning Compute Cluster.
        """
        return pulumi.get(self, "tenant_id")


@pulumi.output_type
class ComputeClusterScaleSettings(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "maxNodeCount":
            suggest = "max_node_count"
        elif key == "minNodeCount":
            suggest = "min_node_count"
        elif key == "scaleDownNodesAfterIdleDuration":
            suggest = "scale_down_nodes_after_idle_duration"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ComputeClusterScaleSettings. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ComputeClusterScaleSettings.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ComputeClusterScaleSettings.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 max_node_count: int,
                 min_node_count: int,
                 scale_down_nodes_after_idle_duration: str):
        """
        :param int max_node_count: Maximum node count. Changing this forces a new Machine Learning Compute Cluster to be created.
        :param int min_node_count: Minimal node count. Changing this forces a new Machine Learning Compute Cluster to be created.
        :param str scale_down_nodes_after_idle_duration: Node Idle Time Before Scale Down: defines the time until the compute is shutdown when it has gone into Idle state. Is defined according to W3C XML schema standard for duration. Changing this forces a new Machine Learning Compute Cluster to be created.
        """
        pulumi.set(__self__, "max_node_count", max_node_count)
        pulumi.set(__self__, "min_node_count", min_node_count)
        pulumi.set(__self__, "scale_down_nodes_after_idle_duration", scale_down_nodes_after_idle_duration)

    @property
    @pulumi.getter(name="maxNodeCount")
    def max_node_count(self) -> int:
        """
        Maximum node count. Changing this forces a new Machine Learning Compute Cluster to be created.
        """
        return pulumi.get(self, "max_node_count")

    @property
    @pulumi.getter(name="minNodeCount")
    def min_node_count(self) -> int:
        """
        Minimal node count. Changing this forces a new Machine Learning Compute Cluster to be created.
        """
        return pulumi.get(self, "min_node_count")

    @property
    @pulumi.getter(name="scaleDownNodesAfterIdleDuration")
    def scale_down_nodes_after_idle_duration(self) -> str:
        """
        Node Idle Time Before Scale Down: defines the time until the compute is shutdown when it has gone into Idle state. Is defined according to W3C XML schema standard for duration. Changing this forces a new Machine Learning Compute Cluster to be created.
        """
        return pulumi.get(self, "scale_down_nodes_after_idle_duration")


@pulumi.output_type
class ComputeClusterSsh(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "adminUsername":
            suggest = "admin_username"
        elif key == "adminPassword":
            suggest = "admin_password"
        elif key == "keyValue":
            suggest = "key_value"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ComputeClusterSsh. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ComputeClusterSsh.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ComputeClusterSsh.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 admin_username: str,
                 admin_password: Optional[str] = None,
                 key_value: Optional[str] = None):
        """
        :param str admin_username: Name of the administrator user account which can be used to SSH to nodes. Changing this forces a new Machine Learning Compute Cluster to be created.
        :param str admin_password: Password of the administrator user account. Changing this forces a new Machine Learning Compute Cluster to be created.
        :param str key_value: SSH public key of the administrator user account. Changing this forces a new Machine Learning Compute Cluster to be created.
               
               > **NOTE:** At least one of `admin_password` and `key_value` shoud be specified.
        """
        pulumi.set(__self__, "admin_username", admin_username)
        if admin_password is not None:
            pulumi.set(__self__, "admin_password", admin_password)
        if key_value is not None:
            pulumi.set(__self__, "key_value", key_value)

    @property
    @pulumi.getter(name="adminUsername")
    def admin_username(self) -> str:
        """
        Name of the administrator user account which can be used to SSH to nodes. Changing this forces a new Machine Learning Compute Cluster to be created.
        """
        return pulumi.get(self, "admin_username")

    @property
    @pulumi.getter(name="adminPassword")
    def admin_password(self) -> Optional[str]:
        """
        Password of the administrator user account. Changing this forces a new Machine Learning Compute Cluster to be created.
        """
        return pulumi.get(self, "admin_password")

    @property
    @pulumi.getter(name="keyValue")
    def key_value(self) -> Optional[str]:
        """
        SSH public key of the administrator user account. Changing this forces a new Machine Learning Compute Cluster to be created.

        > **NOTE:** At least one of `admin_password` and `key_value` shoud be specified.
        """
        return pulumi.get(self, "key_value")


@pulumi.output_type
class ComputeInstanceAssignToUser(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "objectId":
            suggest = "object_id"
        elif key == "tenantId":
            suggest = "tenant_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ComputeInstanceAssignToUser. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ComputeInstanceAssignToUser.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ComputeInstanceAssignToUser.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 object_id: Optional[str] = None,
                 tenant_id: Optional[str] = None):
        """
        :param str object_id: User’s AAD Object Id.
        :param str tenant_id: User’s AAD Tenant Id.
        """
        if object_id is not None:
            pulumi.set(__self__, "object_id", object_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter(name="objectId")
    def object_id(self) -> Optional[str]:
        """
        User’s AAD Object Id.
        """
        return pulumi.get(self, "object_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[str]:
        """
        User’s AAD Tenant Id.
        """
        return pulumi.get(self, "tenant_id")


@pulumi.output_type
class ComputeInstanceIdentity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "identityIds":
            suggest = "identity_ids"
        elif key == "principalId":
            suggest = "principal_id"
        elif key == "tenantId":
            suggest = "tenant_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ComputeInstanceIdentity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ComputeInstanceIdentity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ComputeInstanceIdentity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 identity_ids: Optional[Sequence[str]] = None,
                 principal_id: Optional[str] = None,
                 tenant_id: Optional[str] = None):
        """
        :param str type: Specifies the type of Managed Service Identity that should be configured on this Machine Learning Compute Instance. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both). Changing this forces a new resource to be created.
        :param Sequence[str] identity_ids: Specifies a list of User Assigned Managed Identity IDs to be assigned to this Machine Learning Compute Instance. Changing this forces a new resource to be created.
               
               > **NOTE:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        :param str principal_id: The Principal ID for the Service Principal associated with the Managed Service Identity of this Machine Learning Compute Instance.
        :param str tenant_id: The Tenant ID for the Service Principal associated with the Managed Service Identity of this Machine Learning Compute Instance.
        """
        pulumi.set(__self__, "type", type)
        if identity_ids is not None:
            pulumi.set(__self__, "identity_ids", identity_ids)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Specifies the type of Managed Service Identity that should be configured on this Machine Learning Compute Instance. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both). Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[Sequence[str]]:
        """
        Specifies a list of User Assigned Managed Identity IDs to be assigned to this Machine Learning Compute Instance. Changing this forces a new resource to be created.

        > **NOTE:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        return pulumi.get(self, "identity_ids")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[str]:
        """
        The Principal ID for the Service Principal associated with the Managed Service Identity of this Machine Learning Compute Instance.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[str]:
        """
        The Tenant ID for the Service Principal associated with the Managed Service Identity of this Machine Learning Compute Instance.
        """
        return pulumi.get(self, "tenant_id")


@pulumi.output_type
class ComputeInstanceSsh(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "publicKey":
            suggest = "public_key"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ComputeInstanceSsh. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ComputeInstanceSsh.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ComputeInstanceSsh.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 public_key: str,
                 port: Optional[int] = None,
                 username: Optional[str] = None):
        """
        :param str public_key: Specifies the SSH rsa public key file as a string. Use "ssh-keygen -t rsa -b 2048" to generate your SSH key pairs.
        :param int port: Describes the port for connecting through SSH.
        :param str username: The admin username of this Machine Learning Compute Instance.
        """
        pulumi.set(__self__, "public_key", public_key)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> str:
        """
        Specifies the SSH rsa public key file as a string. Use "ssh-keygen -t rsa -b 2048" to generate your SSH key pairs.
        """
        return pulumi.get(self, "public_key")

    @property
    @pulumi.getter
    def port(self) -> Optional[int]:
        """
        Describes the port for connecting through SSH.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def username(self) -> Optional[str]:
        """
        The admin username of this Machine Learning Compute Instance.
        """
        return pulumi.get(self, "username")


@pulumi.output_type
class InferenceClusterIdentity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "identityIds":
            suggest = "identity_ids"
        elif key == "principalId":
            suggest = "principal_id"
        elif key == "tenantId":
            suggest = "tenant_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InferenceClusterIdentity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InferenceClusterIdentity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InferenceClusterIdentity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 identity_ids: Optional[Sequence[str]] = None,
                 principal_id: Optional[str] = None,
                 tenant_id: Optional[str] = None):
        """
        :param str type: Specifies the type of Managed Service Identity that should be configured on this Machine Learning Inference Cluster. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both). Changing this forces a new resource to be created.
        :param Sequence[str] identity_ids: Specifies a list of User Assigned Managed Identity IDs to be assigned to this Machine Learning Inference Cluster. Changing this forces a new resource to be created.
               
               > **NOTE:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        :param str principal_id: The Principal ID for the Service Principal associated with the Managed Service Identity of this Machine Learning Inference Cluster.
        :param str tenant_id: The Tenant ID for the Service Principal associated with the Managed Service Identity of this Machine Learning Inference Cluster.
        """
        pulumi.set(__self__, "type", type)
        if identity_ids is not None:
            pulumi.set(__self__, "identity_ids", identity_ids)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Specifies the type of Managed Service Identity that should be configured on this Machine Learning Inference Cluster. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both). Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[Sequence[str]]:
        """
        Specifies a list of User Assigned Managed Identity IDs to be assigned to this Machine Learning Inference Cluster. Changing this forces a new resource to be created.

        > **NOTE:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        return pulumi.get(self, "identity_ids")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[str]:
        """
        The Principal ID for the Service Principal associated with the Managed Service Identity of this Machine Learning Inference Cluster.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[str]:
        """
        The Tenant ID for the Service Principal associated with the Managed Service Identity of this Machine Learning Inference Cluster.
        """
        return pulumi.get(self, "tenant_id")


@pulumi.output_type
class InferenceClusterSsl(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "leafDomainLabel":
            suggest = "leaf_domain_label"
        elif key == "overwriteExistingDomain":
            suggest = "overwrite_existing_domain"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InferenceClusterSsl. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InferenceClusterSsl.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InferenceClusterSsl.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cert: Optional[str] = None,
                 cname: Optional[str] = None,
                 key: Optional[str] = None,
                 leaf_domain_label: Optional[str] = None,
                 overwrite_existing_domain: Optional[bool] = None):
        """
        :param str cert: The certificate for the SSL configuration.Conflicts with `ssl[0].leaf_domain_label`,`ssl[0].overwrite_existing_domain`. Changing this forces a new Machine Learning Inference Cluster to be created. Defaults to `""`.
        :param str cname: The cname of the SSL configuration.Conflicts with `ssl[0].leaf_domain_label`,`ssl[0].overwrite_existing_domain`. Changing this forces a new Machine Learning Inference Cluster to be created. Defaults to `""`.
        :param str key: The key content for the SSL configuration.Conflicts with `ssl[0].leaf_domain_label`,`ssl[0].overwrite_existing_domain`. Changing this forces a new Machine Learning Inference Cluster to be created. Defaults to `""`.
        :param str leaf_domain_label: The leaf domain label for the SSL configuration. Conflicts with `ssl[0].cert`,`ssl[0].key`,`ssl[0].cname`. Changing this forces a new Machine Learning Inference Cluster to be created. Defaults to `""`.
        :param bool overwrite_existing_domain: Whether or not to overwrite existing leaf domain. Conflicts with `ssl[0].cert`,`ssl[0].key`,`ssl[0].cname` Changing this forces a new Machine Learning Inference Cluster to be created. Defaults to `""`.
        """
        if cert is not None:
            pulumi.set(__self__, "cert", cert)
        if cname is not None:
            pulumi.set(__self__, "cname", cname)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if leaf_domain_label is not None:
            pulumi.set(__self__, "leaf_domain_label", leaf_domain_label)
        if overwrite_existing_domain is not None:
            pulumi.set(__self__, "overwrite_existing_domain", overwrite_existing_domain)

    @property
    @pulumi.getter
    def cert(self) -> Optional[str]:
        """
        The certificate for the SSL configuration.Conflicts with `ssl[0].leaf_domain_label`,`ssl[0].overwrite_existing_domain`. Changing this forces a new Machine Learning Inference Cluster to be created. Defaults to `""`.
        """
        return pulumi.get(self, "cert")

    @property
    @pulumi.getter
    def cname(self) -> Optional[str]:
        """
        The cname of the SSL configuration.Conflicts with `ssl[0].leaf_domain_label`,`ssl[0].overwrite_existing_domain`. Changing this forces a new Machine Learning Inference Cluster to be created. Defaults to `""`.
        """
        return pulumi.get(self, "cname")

    @property
    @pulumi.getter
    def key(self) -> Optional[str]:
        """
        The key content for the SSL configuration.Conflicts with `ssl[0].leaf_domain_label`,`ssl[0].overwrite_existing_domain`. Changing this forces a new Machine Learning Inference Cluster to be created. Defaults to `""`.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter(name="leafDomainLabel")
    def leaf_domain_label(self) -> Optional[str]:
        """
        The leaf domain label for the SSL configuration. Conflicts with `ssl[0].cert`,`ssl[0].key`,`ssl[0].cname`. Changing this forces a new Machine Learning Inference Cluster to be created. Defaults to `""`.
        """
        return pulumi.get(self, "leaf_domain_label")

    @property
    @pulumi.getter(name="overwriteExistingDomain")
    def overwrite_existing_domain(self) -> Optional[bool]:
        """
        Whether or not to overwrite existing leaf domain. Conflicts with `ssl[0].cert`,`ssl[0].key`,`ssl[0].cname` Changing this forces a new Machine Learning Inference Cluster to be created. Defaults to `""`.
        """
        return pulumi.get(self, "overwrite_existing_domain")


@pulumi.output_type
class SynapseSparkIdentity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "identityIds":
            suggest = "identity_ids"
        elif key == "principalId":
            suggest = "principal_id"
        elif key == "tenantId":
            suggest = "tenant_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SynapseSparkIdentity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SynapseSparkIdentity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SynapseSparkIdentity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 identity_ids: Optional[Sequence[str]] = None,
                 principal_id: Optional[str] = None,
                 tenant_id: Optional[str] = None):
        """
        :param str type: Specifies the type of Managed Service Identity that should be configured on this Machine Learning Synapse Spark. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both). Changing this forces a new resource to be created.
        :param Sequence[str] identity_ids: Specifies a list of User Assigned Managed Identity IDs to be assigned to this Machine Learning Synapse Spark. Changing this forces a new resource to be created.
               
               > **NOTE:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        :param str principal_id: The Principal ID for the Service Principal associated with the Managed Service Identity of this Machine Learning Synapse Spark.
        :param str tenant_id: The Tenant ID for the Service Principal associated with the Managed Service Identity of this Machine Learning Synapse Spark.
        """
        pulumi.set(__self__, "type", type)
        if identity_ids is not None:
            pulumi.set(__self__, "identity_ids", identity_ids)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Specifies the type of Managed Service Identity that should be configured on this Machine Learning Synapse Spark. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both). Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[Sequence[str]]:
        """
        Specifies a list of User Assigned Managed Identity IDs to be assigned to this Machine Learning Synapse Spark. Changing this forces a new resource to be created.

        > **NOTE:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        return pulumi.get(self, "identity_ids")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[str]:
        """
        The Principal ID for the Service Principal associated with the Managed Service Identity of this Machine Learning Synapse Spark.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[str]:
        """
        The Tenant ID for the Service Principal associated with the Managed Service Identity of this Machine Learning Synapse Spark.
        """
        return pulumi.get(self, "tenant_id")


@pulumi.output_type
class WorkspaceEncryption(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "keyId":
            suggest = "key_id"
        elif key == "keyVaultId":
            suggest = "key_vault_id"
        elif key == "userAssignedIdentityId":
            suggest = "user_assigned_identity_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkspaceEncryption. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkspaceEncryption.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkspaceEncryption.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 key_id: str,
                 key_vault_id: str,
                 user_assigned_identity_id: Optional[str] = None):
        """
        :param str key_id: The Key Vault URI to access the encryption key.
        :param str key_vault_id: The ID of the keyVault where the customer owned encryption key is present.
        :param str user_assigned_identity_id: The Key Vault URI to access the encryption key.
               
               > **Note:** `user_assigned_identity_id` must set when`identity.type` is `UserAssigned` or service won't be able to find the assigned permissions.
        """
        pulumi.set(__self__, "key_id", key_id)
        pulumi.set(__self__, "key_vault_id", key_vault_id)
        if user_assigned_identity_id is not None:
            pulumi.set(__self__, "user_assigned_identity_id", user_assigned_identity_id)

    @property
    @pulumi.getter(name="keyId")
    def key_id(self) -> str:
        """
        The Key Vault URI to access the encryption key.
        """
        return pulumi.get(self, "key_id")

    @property
    @pulumi.getter(name="keyVaultId")
    def key_vault_id(self) -> str:
        """
        The ID of the keyVault where the customer owned encryption key is present.
        """
        return pulumi.get(self, "key_vault_id")

    @property
    @pulumi.getter(name="userAssignedIdentityId")
    def user_assigned_identity_id(self) -> Optional[str]:
        """
        The Key Vault URI to access the encryption key.

        > **Note:** `user_assigned_identity_id` must set when`identity.type` is `UserAssigned` or service won't be able to find the assigned permissions.
        """
        return pulumi.get(self, "user_assigned_identity_id")


@pulumi.output_type
class WorkspaceFeatureStore(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "computerSparkRuntimeVersion":
            suggest = "computer_spark_runtime_version"
        elif key == "offlineConnectionName":
            suggest = "offline_connection_name"
        elif key == "onlineConnectionName":
            suggest = "online_connection_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkspaceFeatureStore. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkspaceFeatureStore.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkspaceFeatureStore.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 computer_spark_runtime_version: Optional[str] = None,
                 offline_connection_name: Optional[str] = None,
                 online_connection_name: Optional[str] = None):
        """
        :param str computer_spark_runtime_version: The version of Spark runtime.
        :param str offline_connection_name: The name of offline store connection.
        :param str online_connection_name: The name of online store connection.
               
               > **Note:** `feature_store` must be set when`kind` is `FeatureStore`
        """
        if computer_spark_runtime_version is not None:
            pulumi.set(__self__, "computer_spark_runtime_version", computer_spark_runtime_version)
        if offline_connection_name is not None:
            pulumi.set(__self__, "offline_connection_name", offline_connection_name)
        if online_connection_name is not None:
            pulumi.set(__self__, "online_connection_name", online_connection_name)

    @property
    @pulumi.getter(name="computerSparkRuntimeVersion")
    def computer_spark_runtime_version(self) -> Optional[str]:
        """
        The version of Spark runtime.
        """
        return pulumi.get(self, "computer_spark_runtime_version")

    @property
    @pulumi.getter(name="offlineConnectionName")
    def offline_connection_name(self) -> Optional[str]:
        """
        The name of offline store connection.
        """
        return pulumi.get(self, "offline_connection_name")

    @property
    @pulumi.getter(name="onlineConnectionName")
    def online_connection_name(self) -> Optional[str]:
        """
        The name of online store connection.

        > **Note:** `feature_store` must be set when`kind` is `FeatureStore`
        """
        return pulumi.get(self, "online_connection_name")


@pulumi.output_type
class WorkspaceIdentity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "identityIds":
            suggest = "identity_ids"
        elif key == "principalId":
            suggest = "principal_id"
        elif key == "tenantId":
            suggest = "tenant_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkspaceIdentity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkspaceIdentity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkspaceIdentity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 identity_ids: Optional[Sequence[str]] = None,
                 principal_id: Optional[str] = None,
                 tenant_id: Optional[str] = None):
        """
        :param str type: Specifies the type of Managed Service Identity that should be configured on this Machine Learning Workspace. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        :param Sequence[str] identity_ids: Specifies a list of User Assigned Managed Identity IDs to be assigned to this Machine Learning Workspace.
               
               > **NOTE:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        :param str principal_id: The Principal ID associated with this Managed Service Identity.
        :param str tenant_id: The Tenant ID associated with this Managed Service Identity.
        """
        pulumi.set(__self__, "type", type)
        if identity_ids is not None:
            pulumi.set(__self__, "identity_ids", identity_ids)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Specifies the type of Managed Service Identity that should be configured on this Machine Learning Workspace. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[Sequence[str]]:
        """
        Specifies a list of User Assigned Managed Identity IDs to be assigned to this Machine Learning Workspace.

        > **NOTE:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        return pulumi.get(self, "identity_ids")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[str]:
        """
        The Principal ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[str]:
        """
        The Tenant ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "tenant_id")


@pulumi.output_type
class WorkspaceManagedNetwork(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "isolationMode":
            suggest = "isolation_mode"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkspaceManagedNetwork. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkspaceManagedNetwork.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkspaceManagedNetwork.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 isolation_mode: Optional[str] = None):
        """
        :param str isolation_mode: The isolation mode of the Machine Learning Workspace. Possible values are `Disabled`, `AllowOnlyApprovedOutbound`, and `AllowInternetOutbound`
        """
        if isolation_mode is not None:
            pulumi.set(__self__, "isolation_mode", isolation_mode)

    @property
    @pulumi.getter(name="isolationMode")
    def isolation_mode(self) -> Optional[str]:
        """
        The isolation mode of the Machine Learning Workspace. Possible values are `Disabled`, `AllowOnlyApprovedOutbound`, and `AllowInternetOutbound`
        """
        return pulumi.get(self, "isolation_mode")


@pulumi.output_type
class WorkspaceServerlessCompute(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "publicIpEnabled":
            suggest = "public_ip_enabled"
        elif key == "subnetId":
            suggest = "subnet_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkspaceServerlessCompute. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkspaceServerlessCompute.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkspaceServerlessCompute.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 public_ip_enabled: Optional[bool] = None,
                 subnet_id: Optional[str] = None):
        """
        :param bool public_ip_enabled: Should serverless compute nodes deployed in a custom Virtual Network have public IP addresses enabled for a workspace with private endpoint? Defaults to `false`.
               
               > **Note:** `public_ip_enabled` cannot be updated from `true` to `false` when `subnet_id` is not set. `public_ip_enabled` must be set to `true` if `subnet_id` is not set and when `public_network_access_enabled` is `false`.
        :param str subnet_id: The ID of an existing Virtual Network Subnet in which the serverless compute nodes should be deployed to.
        """
        if public_ip_enabled is not None:
            pulumi.set(__self__, "public_ip_enabled", public_ip_enabled)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)

    @property
    @pulumi.getter(name="publicIpEnabled")
    def public_ip_enabled(self) -> Optional[bool]:
        """
        Should serverless compute nodes deployed in a custom Virtual Network have public IP addresses enabled for a workspace with private endpoint? Defaults to `false`.

        > **Note:** `public_ip_enabled` cannot be updated from `true` to `false` when `subnet_id` is not set. `public_ip_enabled` must be set to `true` if `subnet_id` is not set and when `public_network_access_enabled` is `false`.
        """
        return pulumi.get(self, "public_ip_enabled")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[str]:
        """
        The ID of an existing Virtual Network Subnet in which the serverless compute nodes should be deployed to.
        """
        return pulumi.get(self, "subnet_id")


@pulumi.output_type
class GetWorkspaceIdentityResult(dict):
    def __init__(__self__, *,
                 identity_ids: Sequence[str],
                 principal_id: str,
                 tenant_id: str,
                 type: str):
        """
        :param Sequence[str] identity_ids: A list of User Assigned Identity IDs assigned to this Machine Learning Workspace.
        :param str principal_id: The Principal ID of the System Assigned Managed Identity assigned to this Machine Learning Workspace.
        :param str tenant_id: The Tenant ID of the System Assigned Managed Identity assigned to this Machine Learning Workspace.
        :param str type: The Type of Managed Identity assigned to this Machine Learning Workspace.
        """
        pulumi.set(__self__, "identity_ids", identity_ids)
        pulumi.set(__self__, "principal_id", principal_id)
        pulumi.set(__self__, "tenant_id", tenant_id)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Sequence[str]:
        """
        A list of User Assigned Identity IDs assigned to this Machine Learning Workspace.
        """
        return pulumi.get(self, "identity_ids")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> str:
        """
        The Principal ID of the System Assigned Managed Identity assigned to this Machine Learning Workspace.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> str:
        """
        The Tenant ID of the System Assigned Managed Identity assigned to this Machine Learning Workspace.
        """
        return pulumi.get(self, "tenant_id")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The Type of Managed Identity assigned to this Machine Learning Workspace.
        """
        return pulumi.get(self, "type")


